#!/bin/bash
#
#########################################################################################
#
# Program Name: L2P_proc.sh
#
# Purpose: Generate L2P format files then distribute to server
#
# Usage:  L2P_proc.sh $1
#    $1: A SST area number, such as 142, 242, 182, 162,..
#
# Prerequisite: The SST retrieval has been completed, three files containing the required 
#               SST information are created which are called L2P.NNNN.header, L2P.NNNN.nav,
#               L2P.NNNN.data (NNNN=0$1).      
#
# Called by: "proc" program such as proc_msg.sh, proc_gen.sh ...
#
# Scripts called: set_app_env.sh 
#                 sendL2P_goes.sh, sendL2P_msg.sh, or sendL2P_mtsat.sh
#
# Program called: makeGHRSST-2.0-level2p-DW.x,  testGhrsst-level2p.x
#
#
# Change History:
#     Mar. 2009   M. Fan  (PSGS)
#                 Modified from procCrtmB_L2P_test.sh 
#
#########################################################################################
#

doecho() { echo $@ ; eval $@ ; }

## Set directories and  environment variables
#---------------------------------------------
export SCRIPTDIR=$( dirname $0 )
. $SCRIPTDIR/set_app_env.sh
scriptname=$( basename $0)

# info from PROC.TABLE: scripts and other viriables
#----
## set TABLE name
table=$SCRIPTDIR/PROC.TABLE
# region name
#----
[[ $1 -eq 142 || $1 -eq 542 ]]   &&  RegName=GOES_NE
[[ $1 -eq 242 || $1 -eq 642 ]]   &&  RegName=GOES_NW
[[ $1 -eq 342 || $1 -eq 742 ]]   &&  RegName=GOES_SE
[[ $1 -eq 442 || $1 -eq 842 ]]   &&  RegName=GOES_SW
[[ $1 -eq 162               ]]   &&  RegName=MTSAT
[[ $1 -eq 182 || $1 -eq 282 || $1 -eq 382 || $1 -eq 482 ]]   &&  RegName=MSG
echo "RegName=$RegName"
## get all info related with $RegName
#----
RegInfo=$( grep -ve ^# $table | grep -e $RegName )
isOps=$( echo $RegInfo | awk -F\, '{print $2}' | awk -F\/ '{print $1}' )
isTest=$( echo $RegInfo | awk -F\, '{print $2}' | awk -F\/ '{print $2}' )
isBackup=$( echo $RegInfo | awk -F\, '{print $2}' | awk -F\/ '{print $3}' )


## set log file:
##--------------
#datestring=`date -u +%Y.%j`
#logname=$(echo $scriptname | sed s/\.sh$// )
#logname="$logname.$datestring.log"
#LOGFILE=$LOGDIR/$logname
#exec >> $LOGFILE   2>&1

## Usage Prompt 
#-----------------------
#echo "Begin $scriptname $* at $(date)"
if [ $# -ne 1 ]
then
    echo "USAGE:    $scriptname  $1 "
    echo 'e.g.      $scriptname  142 '
    exit -1
fi

## message
#-----------------
echo " "
echo " "
echo "================================================================"
echo " Begin  $scriptname $* at $(date)"              # time stamp

echo  "L2P_DATA   = $L2P_DATA"
echo  "L2P_OUTDIR = $L2P_OUTDIR"
echo  "L2P_INDIR  = $L2P_INDIR"
echo  "L2P_OLDIN  = $L2P_OLDIN"



#  netcdf converter exewcutable
#------------------------------
makeGHRSSTlevel2p_exe=${BINDIR}/makeGHRSST-2.0-level2p-DW.x

## get SST AREA:
#---------------
IAREA=0$1
echo " SST AREA is: $IAREA"

##  NET_CDF CONVERSION
#------------------------
cd $MCDATDIR

 image=$IAREA
 name=L2P.$image
 if [ -s ${L2P_INDIR}/$name.data ]
 then
    echo
    doecho  $makeGHRSSTlevel2p_exe $name > $LOGDIR/$name.log
    l2pErr=$?
    cat $LOGDIR/$name.log
    if [ $l2pErr -ne 0 ]
    then
       echo " ERROR $l2pErr from $makeGHRSSTlevel2p_exe for $name - `date`"
       echo "l2p generate FAIL"
    else
       echo "l2p generate SUCCESS"
    fi

# For GHRST-2.0  we don't have format checker.  Cancel this test.
#  -- verify the integrity of L2P
#   testGhrsst-level2p.x  $name
    echo " Skip  execution of testGhrsst-level2p.x  $name "    
    test_err=$?
    if [ $test_err -ne 0 ]; then
        echo "L2P error reported by testGhrsst-level2p.x   $test_err"
    else
# -- L2P product name
        tmp_prod=$( cat $LOGDIR/$name.log |grep 'L2P: Writing to file' )
        prod_name=$( echo $tmp_prod |awk -F\/ '{print $6}' )
        echo "prod_name=$prod_name"


## ------- In netCDF-2.0 
##  a)  Do Not compress the L2P files; internal compression already in place
##  b)  No xml file: metadata is internal
#

#    Generate checksum files
       cd $L2P_OUTDIR
       md5file=$prod_name.md5
       md5sum   $prod_name  >  $md5file

## -- Send to server
       echo 
       echo "Sending to server............."
       echo
       #echo $prod_name |grep GOES   &&   sendL2P_script=sendL2P_goes.sh
       #echo $prod_name |grep MTSAT  &&   sendL2P_script=sendL2P_mtsat.sh
       #echo $prod_name |grep MSG    &&   sendL2P_script=sendL2P_msg.sh

       export sendL2P_script=sendL2P_2.0.sh 

       echo "isOps=$isOps"       |grep TRUE   &&   doecho   $SCRIPTDIR/$sendL2P_script   isOps    $prod_name
       echo "isTest=$isTest"     |grep TRUE   &&   doecho   $SCRIPTDIR/$sendL2P_script   isTest   $prod_name
       echo "isBackup=$isBackup" |grep TRUE   &&   doecho   $SCRIPTDIR/$sendL2P_script   isBackup $prod_name

    fi
 else
    echo "Input L2P dataset not found ${L2P_INDIR}/$name.data "
    ls -ltr  ${L2P_INDIR}/$name.data  |tail -12
 fi

#
cd $MCDATDIR
echo "`date -u` end $scriptname"		# timestamp

