#! /bin/sh
#
#######################################################################################
#
# Program Name: send_dds_gzip.sh
#
# Purpose: Send geosst products to dds, gzipped
#
# Usage: send_ddz_gzip.sh    Filepath/Filename
#       Note that if file not compressed,  this will create temporary compressed version
#       Example:  send_dds_gzip.sh  sst1b_2009_365_13A
#
# Logic:
#    Need local file directory, local file name, holding directory, remote info
#    Verify directories, file exist
#    Link or create zipped file in holding directory
#    copy file to dds
#       copy as <file>.xfer
#       rename to <file>
#       delete from holding directory
#       log successful transfer
#    If fail at any point, log error in transfer
#
# Called by: merge_*, buoyMatch*
#
#    12/05/14  B Potash    Initial version
#              1) 
#
#######################################################################################
#


## Set directories and  environment variables for both local and server
#-----------------------------------------------------------------------
 export SCRIPTDIR=$( dirname $0 )
. $SCRIPTDIR/set_app_env.sh

 export scriptname=$( basename $0 )
 export curDir=`pwd`
 export  ERR="!! $scriptname ERROR:"

# log file for sending
#---------------------------------------------------------------------
 export  datestring=`date -u +%Y%j`
 export  logname=sendlog.$(whoami).$(hostname -s).$datestring
 export  SENDLOG=$LOGDIR/$logname
 export  TEMPLOG=$LOGDIR/sendlogTemp.$$
#export  XFERDIR=/data/$(whoami)/xferData      # done in set_app_env
#exec >> $SENDLOG   2>&1

## message
 echo " "
 echo "================================================================"
 echo "`date -u` start $scriptname"              # time stamp

## Usage prompt
#----------------------------
 if [ $# -lt 1 ]
 then
    echo "USAGE:   $scriptname  FileToSend"
    exit -1
 fi

 FileToSend=$1

# Define and verify local directories and file-to-send
#-------------------------------------------------

 remoteServer=10.144.3.7       # DDS
 remoteUser="F0243"            # geo_sst account on DDS
 remoteDir=push

 localDir=$(  dirname  $FileToSend)
 localName=$( basename $FileToSend)

 [ ! -f  $localDir/$localName ] &&  echo "$ERR - File $FileToSend Not Found" && exit 1
 [   -d $XFERDIR ]              ||  mkdir  $XFERDIR
 [ ! -d $XFERDIR ]              &&   echo "$ERR - xferdir $XFERDIR Not Found" && exit 1

# If  L2P/GRHRSST file, or gzipped file,  Link to xfer directory
# Or  create temporary zipped version in xfer directory
#-------------------------------------------------
 
 echo $localName  | grep  "GHRSST"  > /dev/null  2>&1
 rc1=$?
 echo $localName  | grep  "gz"      > /dev/null  2>&1
 rc2=$?

 echo " File=$localName  GHRSSTflag=$rc1 ; gzippedflag=$rc2"

 if  [[ $rc1 -eq 0 ]]  ||  [[ $rc2 -eq 0 ]]
 then                         # GRRST files go uncompressed
   #  local file is GHRSST or already zipped.  ; send exact file"
   remoteName=$localName
   [ -h $XFERDIR/$remoteName ]  || ln -s    $localDir/$localName   $XFERDIR/$remoteName
   rc=$?

 else      
     #  local file neither GHRST nor gzipped - must gzip  gzip
     remoteName=$localName.gz
     [ -f $XFERDIR/$remoteName ]  || gzip -c  $localDir/$localName > $XFERDIR/$remoteName
     rc=$?
        echo "DEBUG: file to send:  $XFERDIR/$remoteName "
        echo "DEBUG: ls -l gives `ls -l  $XFERDIR/$remoteName `"
 fi
 [ $rc -ne 0 ]  &&  echo "$ERR $rc putting $remoteName in $XFERDIR"  &&  exit 1
        echo "DEBUG3"


# Put file on remote server
#    first as <name>.xfer, then rename to strip .xfer
#-------------------------------------------------
 xfer_script=./xferScript.$$

        echo "DEBUG4    xfer_script=$xfer_script"

 temp_remoteName="xfr_${remoteName}"

 cat  <<ENDCAT  >$xfer_script
   ftptime  -200   -v   $remoteServer  <<ENDFTP    >  $TEMPLOG  2>&1
   cd  $remoteDir
      put $XFERDIR/${remoteName}  ${temp_remoteName}
      rename  $temp_remoteName   ${remoteName}
      dir ${remoteName}
   ENDFTP
ENDCAT

 echo " ------------------------ begin ftp script -----------------------------"
   cat $xfer_script
 echo " ------------------------   end ftp script -----------------------------"

 echo " ------------------------ begin execute  script -----------------------------"
 sh $xfer_script
 rc1=$?
 echo " ------------------------   end execute  script -----------------------------"

mv $xfer_script $LOGDIR

 grep 'Transfer complete'  $TEMPLOG  >/dev/null  2>&1   ;  rc2=$?
 grep 'Rename successful'  $TEMPLOG  >/dev/null  2>&1   ;  rc3=$?
 if [ $rc1 -ne 0 ] 
 then
     echo " $ERR sending $localName - ftptime timed out "
 elif [ $rc2 -ne 0 ] 
 then
     echo " $ERR sending $localName - did not detect SUCCESS message "
 elif [ $rc3 -ne 0 ] 
 then
     echo " $ERR sending $localName - did not detect rename .xfer message "
 else
    echo Success  $localName sent to DDS at $(date)  |tee   -a   $TEMPLOG
 fi

let rcsum=$rc1+$rc2+$rc3

 if [ $rc  -eq  0 ]
 then
    echo Success  $localName sent to DDS at $(date)  |tee  -a   $TEMPLOG
 else
    echo Failure  $localName  not sent to DDS at $(date)  |tee  -a   $TEMPLOG
 fi

 rm $XFERDIR/$remoteName
 [ -f $TEMPLOG ]  &&  cat $TEMPLOG >> $SENDLOG  && rm $TEMPLOG
 

 echo "End $scriptname  $* at $(date)"
 echo "================================="
 exit $rcsum





#226 Transfer complete.
#26 bytes sent in 3.7e-05 seconds (6.9e+02 Kbytes/s)
#ftp> rename testfile.xfer testfile
#350 Ready for RNTO.
#250 Rename successful.

