#! /bin/sh
#
#######################################################################################
#
# Program Name: send_fronts_dds.sh  
#
# Purpose: Send geosst frontal products to dds, gzipped
#     QUICK AND DIRTY
#
# Usage: send_fronts_dds.sh  <date - yyyyddd>    
#       Assumes fioles from previous day unless specified
#       Example:  send_dds_gzip.sh  sst1b_2009_365_13A
#
# Logic:
#    Need local file directory, local file name, holding directory, remote info
#    Verify directories, file exist
#    Link or create zipped file in holding directory
#    copy file to dds
#       copy as <file>.xfer
#       rename to <file>
#       delete from holding directory
#       log successful transfer
#    If fail at any point, log error in transfer
#
#   FILES TO SEND - from vsftpd.log on satepsdist1:
#   Directory= /data/sstgeo/front_sst/daily_fronts/
#   Filenames are 
# ---- gsst_2014_360_frt.Z
# ---- gsst_2014_360_frt_valid.dat.Z
# ---- gsst_2014_360_frt.png
# ---- gsst_gulf_10km_2014_360_frt.png
# ---- gsst_gulf_20km_2014_360_frt.png
#
# Called by: cron
#
#    12/28/14  B Potash    Initial version
#              1) 
#
#######################################################################################
#


## Set directories and  environment variables for both local and server
#-----------------------------------------------------------------------
 export SCRIPTDIR=$( dirname $0 )
. $SCRIPTDIR/set_app_env.sh

 export scriptname=$( basename $0 )
 export curDir=`pwd`
 export  ERR="!! $scriptname ERROR:"

# log file for sending
#---------------------------------------------------------------------
 export  datestring=`date -u +%Y%j`
 export  logname=sendlog.$(whoami).$(hostname -s).$datestring
 export  SENDLOG=$LOGDIR/$logname
 export  TEMPLOG=$LOGDIR/sendlogTemp.$$
#export  XFERDIR=/data/$(whoami)/xferData      # done in set_app_env
#exec >> $SENDLOG   2>&1

if [ $# -gt 0 ] 
then
   target_date=$1
else
   target_date=$( date -u  +%Y%j -d'yesterday' )
fi
if [[ $target_date -lt 1970000 ]] || [[ $target_date -gt 2170000 ]]
then
   echo " $0 : $ERR : target_date=$target_date out of range "
   exit 1
fi

yyyy=$( echo $target_date|cut -c1-4)
jjj=$( echo $target_date|cut -c5-7)
datestring="${yyyy}_${jjj}"


FRONT_DIR=/data/$(whoami)/front_sst/daily_fronts/
name1=gsst_${datestring}_frt
name2=gsst_${datestring}_frt_valid.dat
name3=gsst_${datestring}_frt.png
name4=gsst_gulf_10km_${datestring}_frt.png
name5=gsst_gulf_20km_${datestring}_frt.png

for name in  $name1   $name2 
do
   if  [ -s  $FRONT_DIR/$name.Z ]
   then
       cp  $FRONT_DIR/$name.Z  /tmp/$name.Z
       uncompress              /tmp/$name.Z
       gzip                    /tmp/$name
       cp                      /tmp/$name.gz  $FRONT_DIR
       rm  /tmp/$name.*
   fi
done

for name in $name1.gz $name2.gz $name3 $name4 $name5
do
    FileToSend=$FRONT_DIR/$name
    
    ftpdds-fronts.sh   $FileToSend

done





   


## message
 echo " "
 echo "================================================================"
 echo "`date -u` start $scriptname"              # time stamp

## Usage prompt
#----------------------------
 if [ $# -lt 1 ]
 then
    echo "USAGE:   $scriptname  FileToSend"
    exit -1
 fi

 FileToSend=$1

# Define and verify local directories and file-to-send
#-------------------------------------------------

 remoteServer=10.144.3.7       # DDS
 remoteUser="F0243"            # geo_sst account on DDS
 remoteDir=push

 localDir=$(  dirname  $FileToSend)
 localName=$( basename $FileToSend)

 [ ! -f  $localDir/$localName ] &&  echo "$ERR - File $FileToSend Not Found" && exit 1
 [   -d $XFERDIR ]              ||  mkdir  $XFERDIR
 [ ! -d $XFERDIR ]              &&   echo "$ERR - xferdir $XFERDIR Not Found" && exit 1

# If  L2P/GRHRSST file, or gzipped file,  Link to xfer directory
# Or  create temporary zipped version in xfer directory
#-------------------------------------------------
 
 echo $localName  | grep  "GHRSST"  > /dev/null  2>&1
 rc1=$?
 echo $localName  | grep  "gz"      > /dev/null  2>&1
 rc2=$?

 echo " File=$localName  GHRSSTflag=$rc1 ; gzippedflag=$rc2"

 if  [[ $rc1 -eq 0 ]]  ||  [[ $rc2 -eq 0 ]]
 then                         # GRRST files go uncompressed
   #  local file is GHRSST or already zipped.  ; send exact file"
   remoteName=$localName
   [ -h $XFERDIR/$remoteName ]  || ln -s    $localDir/$localName   $XFERDIR/$remoteName
   rc=$?

 else      
     #  local file neither GHRST nor gzipped - must gzip  gzip
     remoteName=$localName.gz
     [ -f $XFERDIR/$remoteName ]  || gzip -c  $localDir/$localName > $XFERDIR/$remoteName
     rc=$?
        echo "DEBUG: file to send:  $XFERDIR/$remoteName "
        echo "DEBUG: ls -l gives `ls -l  $XFERDIR/$remoteName `"
 fi
 [ $rc -ne 0 ]  &&  echo "$ERR $rc putting $remoteName in $XFERDIR"  &&  exit 1
        echo "DEBUG3"


# Put file on remote server
#    first as <name>.xfer, then rename to strip .xfer
#-------------------------------------------------
 xfer_script=./xferScript.$$

        echo "DEBUG4    xfer_script=$xfer_script"

 temp_remoteName="xfr_${remoteName}"

 cat  <<ENDCAT  >$xfer_script
   ftptime  -200   -v   $remoteServer  <<ENDFTP    >  $TEMPLOG  2>&1
   cd  $remoteDir
      put $XFERDIR/${remoteName}  ${temp_remoteName}
      rename  $temp_remoteName   ${remoteName}
      dir ${remoteName}
   ENDFTP
ENDCAT

 echo " ------------------------ begin ftp script -----------------------------"
   cat $xfer_script
 echo " ------------------------   end ftp script -----------------------------"

 echo " ------------------------ begin execute  script -----------------------------"
 sh $xfer_script
 rc1=$?
 echo " ------------------------   end execute  script -----------------------------"

echo "  ----- Begin  xfer_script   -----" >> $TEMPLOG
cat  $xfer_script                         >> $TEMPLOG
echo "  -----   End  xfer_script   -----" >> $TEMPLOG
rm   $xfer_script
echo "  -----   End  xfer_script   -----"

 grep 'Transfer complete'  $TEMPLOG  >/dev/null  2>&1   ;  rc2=$?
 grep 'Rename successful'  $TEMPLOG  >/dev/null  2>&1   ;  rc3=$?
 if [ $rc1 -ne 0 ] 
 then
     echo " $ERR sending $localName - ftptime timed out "
 elif [ $rc2 -ne 0 ] 
 then
     echo " $ERR sending $localName - did not detect SUCCESS message "
 elif [ $rc3 -ne 0 ] 
 then
     echo " $ERR sending $localName - did not detect rename .xfer message "
 else
    echo Success  $localName sent to DDS at $(date)  |tee   -a   $TEMPLOG
 fi

let rcsum=$rc1+$rc2+$rc3

 if [ $rc  -eq  0 ]
 then
    echo Success  $localName sent to DDS at $(date)  |tee  -a   $TEMPLOG
 else
    echo Failure  $localName  not sent to DDS at $(date)  |tee  -a   $TEMPLOG
 fi

 rm $XFERDIR/$remoteName



 echo "End $scriptname  $* at $(date)"
 echo "================================="
 exit $rcsum

