#!/bin/bash
#
#######################################################################################
#
# Program Name: getdata_gen.sh
#
# Purpose: Get input imagery for GOESS-NE SST 
#         -- Fetch imagery to make a multi-spectral AREA file, and
#            put to LD/GOES_NE_IMG. If it fails to do so, return value is -1
#
# Usage: getdata_gen.sh [-l {logfile_name}]
#    -l {logfile_name}: if command line includes logfile name, send stdout to the file
#                       $logfile_name.$datestring.log, where datestring=`date -u +%j.%H%M`,
#                       the time that the script start to run.
#
# Prerequisite: export age
#
# Called by: proc_gen.sh
#
# Scripts called: set_app_env.sh, areaSpecs.sh
#
# Program called: avgimi,  gimiglue
#
# Change History:
## 98/09/03 Activate GOES-WEST SH. Increase search range to +/- 14 min.
# 99/10/09 Switch from ORA to GER/GWR.
# 00/07/17 Separate processing at 15 & 45 minutes.
# 00/09/11 Separate input imagery files for each dataset
# 00/09/22 (1338)  extend GES time range from 35-44  to 35-45
# 00/10/02 Check -l flag for log name
# ???????? Adapt for Linux ; use areaSpecs
# 03/03/03 Adapt to cope with goes-12/band6
# 03/24/2009   M. Fan  (PSGS)
#            1) Add comment blocks
#            2) Set directories and  environment variables by calling set_app_env.sh
#            3) Add LD/GOES_NE_IMG  
#
#######################################################################################

## Set directories and  environment variables
#---------------------------------------------
export SCRIPTDIR=$( dirname $0 )
. $SCRIPTDIR/set_app_env.sh
scriptname=$( basename $0 )

RegName=GOES_NE

# set log file:
# If command line includes logfile name, send stdout to that file
# This avoids e-mail every time the script runs from crontabs
#----------------------------------------------------------------
while getopts l: optionName
do
            case $optionName in
            l)   filename="$OPTARG"
                 datestring=`date -u +%j.%H%M` 
                 filename="$filename.$datestring.log"
                 exec >> $LOGDIR/$filename   2>&1 ;;
            ?)   echo "Usage: $scriptname  -l logfile_name \n";;
           esac
done


echo "================================================================="
echo "`date -u` start $scriptname"       # time stamp


# Change to data directory
#--------------------------
cd $MCDATDIR


# Get specs for input image locations
#------------------------
. $SCRIPTDIR/areaSpecs.sh

echo "WHERE_GENI  =  $WHERE_GENI"


## Set time reference for data to be processed
#               ----------------------------- areaSpecs
#               GOES EAST Northern Hemisphere
#               -----------------------------
#               Data come at 15 & 45 minutes of the hour
#               Download (hh-1):45 data around hh:15
#               Download hh:15 data around hh:45
#
#  -- want $age minutes ago data
##           >> need an exported variable age <<<
#age=60 or 0
#------------------------------------------------------------------------------
date=$(   date +%Y%j  -u -d"$age minutes ago" )      # want $age minutes ago data
hour=$(   date +%H    -u -d"$age minutes ago" )
minute=$( date +%M    -u -d"$age minutes ago" )
echo "$0 DEBUG: age=$age"

#               ---------------------
#               Check starting minute
#               ---------------------
min=`date -u +%M`               # starting minute of the hour - 15 or 45

if [[ $minute -lt 30 ]]; then
   if [[ $min -gt 29  ||  $min -lt 1 ]]; then
          echo Unexpected starting minute not within 05-15. Will exit.
          exit 1
   fi
   min1=35; min2=55
fi
if [[ $minute -ge 30 ]]; then
   if [[ $min -gt 59  || $min -lt 31 ]]; then
       echo Unexpected starting minute of $min, instead of 45. Will exit.
       exit 1
   fi
   min1=05; min2=25
fi


WHEN=" DAY=$date  TIME=$hour:$min1 $hour:$min2 "

echo " $0 DEBUG: Current time is `date`"

echo "GOES-E NHem image between   $hour:$min1 and $hour:$min2 on date $date"


# Check if we already have this image
# If it already existed,exit.Ootherwise
#  continue the processing
#--------------------------------------
imglist.k  LD/${RegName}_IMG.ALL    $WHEN   >/dev/null 2>&1
if  [ $?  -eq 0 ]
then
     echo " Already have ${RegName} imagery for $WHEN ; exiting $0"
     exit
fi

# Remove transition files  
#-----------------
imgdel.k LD/A.1910
#####   Trust without verification #####imgdel.k LD/A.0911 915
imgdel.k LD/A.0912 915


#   Copy the five band data  
#--------------------------------
echo " imgcopy.k GER/GENHEM01V  LD/A.1910 $WHERE_GENV $SIZE_GENV $WHEN"
       imgcopy.k GER/GENHEM01V  LD/A.1910 $WHERE_GENV $SIZE_GENV $WHEN
       imgcopy.k GER/GENHEM04I2 LD/A.0912 $WHERE_GENI $SIZE_GENI $WHEN
       imgcopy.k GER/GENHEM04I3 LD/A.0913 $WHERE_GENI $SIZE_GENI $WHEN
       imgcopy.k GER/GENHEM04I4 LD/A.0914 $WHERE_GENI $SIZE_GENI $WHEN
       imglist.k LD/A.914
       if [ $? -eq 0 ]
       then
          line=`imglist.k LD/A.914 FORM=EXP| grep "ss:"`
          satSensor=`echo $line|awk -F\: '{print $5}'`
          if [ $satSensor -le 76 ] ; then
             imgcopy.k GER/GENHEM04I5 LD/A.0915 $WHERE_GENI $SIZE_GENI $WHEN
          else
             imgcopy.k GER/GENHEM04I6 LD/A.0915 $WHERE_GENI $SIZE_GENI $WHEN
          fi
       fi
echo "Got GOES-E NHem at `date -u`"


#
#   Average visible data to 4-km resolution  
#---------------------------------------------
avgimi.k 1910 911 4
imgdel.k LD/A.1910

#   Combine the five band into one AREA-file  
#---------------------------------------------
num=1
name0=$AREADIR/AREA09$num
InList=`echo $name0"2" $name0"1" $name0"3" $name0"4" $name0"5"`
OutFile=$AREADIR/AREA09${num}"8"
                        echo "debug: InList=$InList"
                        echo "debug: OutFile=$OutFile"
    rm -f $OutFile
                        echo "gimiglue $OutFile  $InList"
  gimiglue $OutFile  $InList


# delete garbage in and print error message
#---------------------------------------------
if [ $? -ne 0 ]
then
  echo "Error in gimiglue for $OutFile"
fi
imglist.k  LD/A.09${num}"0"  09${num}"8"
if [ $? -ne 0 ]
then
  echo "Error Code $?  in imglist for $OutFile"
  rm -f $OutFile
fi
# if Nonextistent or zero-sized outfile  $OutFile, exit the program with -1
if [ ! -s $OutFile ]
then
  rm -f $OutFile 
  echo "Nonextistent or zero-sized outfile  $OutFile"
  echo "Exit getdata_ program with return value of -1"
  echo " End $scriptname at `date -u` " 
  exit -1
fi


# copy to area loop:  LD/${RegName}_IMG
#--------------------------------------------
imglist.k LD/A.09${num}"8"
imglist.k LD/${RegName}_IMG

imgcopy.k  LD/A.09${num}"8"  LD/${RegName}_IMG    BAND=ALL SIZE=SAME


echo "`date -u` done copying data"
echo " End $scriptname at `date -u` "	# time stamp
echo " "
echo "================================================================="

