#!/bin/ksh
#
#######################################################################################
#
# Program Name: getmod.sh
#
# Purpose: Fetch model data
#
# Usage: getmod.sh [-l {logfile_name}]
#    -l {logfile_name}: if command line includes logfile name, send stdout to the file
#                       $logfile_name.$datestring.log, where datestring=`date -u +%j`,
#                       the time that getmod.sh start to run.
#
# Prerequisite: None
#
# Called by: None
#
# Description: Fetch model data and put to LD/G_ATM.$grid_hour and LD/G_SURF.$grid_hour
#              for atmospheric profile and surface data, respectively.
#              $grid_hour is current hour (1-24) that the script starts to run
#        Note: model data is 6-hourly data and we require hourly data, so the model data
#              need to be interpolated some how.
#
#
# Scripts called: set_app_env.sh 
#
# Program called: modsfcgsst.k, modfetch_gsst.k
#
# Exported variable: None
#
# Change History:
#   ????? 
#   09/02/24   M. Fan  (PSGS)
#         1) Add comment blocks
#         2) Set directories and  environment variable by calling set_app_env.sh
#         3) Set directories (archive, DATA) using export variables from set_app_env.sh
#
#######################################################################################

## Set directories and  environment variables
#---------------------------------------------
export SCRIPTDIR=$( dirname $0 ) 
. $SCRIPTDIR/set_app_env.sh
scriptname=$( basename $0 )


# set log file:
# If command line includes logfile name, send stdout to that file
# This avoids e-mail every time the script runs from crontabs
#----------------------------------------------------------------
while getopts l: optionName
do
            case $optionName in
            l)   filename="$OPTARG"
#                datestring=`date -u +%j.%H%M`
                 datestring=`date -u +%j`
                 exec >> $LOGDIR/$filename.$datestring.log 2>&1 ;;
            ?)   echo "Usage: $scriptname  -l logfile_name \n";;
           esac
done

echo "===================================================="
echo " Start $scriptname at $(date -u)"


# go to mcidas data directory
#-----------------------------
##.  $HOME/getpath
#.  $HOME/mcidas/ksh/getpath
#PATH=$HOME/mcidas/bin:$PATH
#cd $HOME/mcidas/data
cd $MCDATDIR


#   export  HHMM1=$1
#---------------------
mcenv << 'EOFMF'
   doecho()
   {
        echo "$@"
        eval "$@"
   }

## set directories
#------------------------
   curdir=`pwd`
#  archive=/data/$(whoami)/modelArchive
#  DATA=$HOME/mcidas/data
#  cd $DATA 
   archive=$MOD_ARCHIVE_DIR
   DATA=$MCDATDIR
   cd $DATA

   echo "archive dir: $archive"
   echo "DATA: $DATA"

## Set time and coverage reference
#-----------------------------------
   model_date=`date  -u +%Y%j`
   hh=`        date  -u +%H  `
   hhmm=${hh}'00'
   hhmmss=${hhmm}'00'
   model_time=${hhmmss}

   COVERAGE=" LAT=-40 65   LON=10 180   INC= 10  "
   EPOCH=" TIME=$model_time  DAY=$model_date  "

## Fetch desired model data and write them as McIDAS GRID files by calling
#  modsfcgsst.k and modfetch_gsst.k
#---------------------------------------------------------------------

#     ---- model profile data

   ATMPARMS=" MODFIL=modeld_atm26  TMPGRD=4751  GRIDF=4752 "

   igu.k DEL  LD/G.4751 LD/G.4752

   doecho  modfetch_gsst.k  $EPOCH   $COVERAGE  $ATMPARMS 
 
#     ---- time stamp: $grid_hour can be 1-24
   grid_hour=$( expr $hh  + 0 )  
   [ $grid_hour -lt 1 ] && grid_hour=24
   
#     ----  put the disired data to LD/G_ATM.$grid_hour 
   doecho  grdcopy.k  LD/G.4752  LD/G_ATM26.$grid_hour     NUM=ALL  DEL=YES

EOFMF

echo " End $scriptname at $(date -u)"
echo "===================================="
cd $curdir
