#!/bin/bash
#
#######################################################################################
#
# Program Name: merge_goes.sh
#
# Purpose:   generate GOES SST gridded fields (hourly, 3-hourly, and daily) 
#            and distribute to product server.
#
# Usage: merge_goes.sh [-l {logfile_name}]
#    -l {logfile_name}: if command line includes logfile name, send stdout to the file
#                       $logfile_name.$datestring.log, where datestring=`date -u +%j.%H%M`,
#                       the time that the script start to run.
#        -- Suggest run within 1st half of hour, e.g. at minute of 25
#
# Prerequisite: Runs after proc_goes.sh put the SST and Pclear AREA files to 
#               LD/GOES_NE_SST,  LD/GOES_SE_SST,  LD/GOES_NW_SST,  LD/GOES_SW_SST,
#               LD/GOES_NE_PCLR, LD/GOES_SE_PCLR, LD/GOES_NW_PCLR, LD/GOES_SW_PCLR 
#
# Called by: None
#
# Description: Select GOES SST and Pclear AREA files, then run merge program to
#              generate SST and Pclear grid field files,and send them to product server
#          1. Set time reference to choose GOES SST and Pclear AREA files
#             Suppose current time is hh:mm (mm > 00), the selected epoch should be the one at
#             hh-2:15, hh-2:45, and hh-1:15 to produce SST hourly at hh-1, for GOES_NE as an example
#             (hh-1, hh-2 stands for one and two hours ago from current hour hh)
#             GOES IMAGE EPOCH:
#                NE --  (hh-2):15                |  (hh-2):45      |  (hh-1):15
#                SE --  (hh-2):09/15 ((hh-3):45) |  (hh-2):39/45   |  (hh-1):09/15 ((hh-2):45)
#                SW --  (hh-2):22    ((hh-2):00) |  (hh-2):52      |  (hh-1):22    ((hh-1):00)
#                NW --  (hh-2):30                |   (hh-1):00     |  (hh-1):30
#          2. Perform hourly merge to generate hourly grid SST and PClear at (hh-1) 
#             then send to product server
#             -- 1 hour back from current (once per hour)
#          3. Perform 3-hourly merge to .......
#             -- 2 hour back from current when current is 04Z, 07Z,... (once per 3 hr)
#          4. Perform daily merge to ........
#             -- one day back from current when current is 04Z (once per day)
#
# Scripts called:
#          1. set_app_env.sh
#          2. send1b_goes_daynite.sh
#          3. send3b_goes.sh
#          4. send24b_goes.sh
#          5. set_server_Ops.sh, set_server_Test.sh, or set_server_Backup.sh by (2, 3, 4)
#
# Program called:
#          1. mergeb1.daynite_test.k
#          2. mergeb3.k
#          3. mergeb24.k
#
# Change History:
#      07/12/27  Modified from procCrtmA_L2P.sh for GOES?
#      09/03/13  M. Fan  (PSGS)
#                1) Add comment blocks
#                2) Use set_app_env.sh
#                3) Apply 2009 version of merge programs
#              -- modified from merge_msg.sh (2009 version)
#
#######################################################################################

doecho() { echo $@ ; eval $@ ; }

## Set directories and  environment variables
#---------------------------------------------
export SCRIPTDIR=$( dirname $0 )
. $SCRIPTDIR/set_app_env.sh
scriptname=$( basename $0)
 

#bindir=$HOME/mcidas/bin
#datadir=$HOME/mcidas/data
bindir=$BINDIR
datadir=$MCDATDIR


# info from PROC.TABLE: scripts and other viriables
#----
## set TABLE name
table=$SCRIPTDIR/PROC.TABLE
# region name
#----
RegName=GOES_NE
## get all info related with $RegName
#----
RegInfo=$( grep -ve ^# $table | grep -e $RegName )
isOps=$( echo $RegInfo | awk -F\, '{print $2}' | awk -F\/ '{print $1}' )
isTest=$( echo $RegInfo | awk -F\, '{print $2}' | awk -F\/ '{print $2}' )
isBackup=$( echo $RegInfo | awk -F\, '{print $2}' | awk -F\/ '{print $3}' )


# set log file:
# If command line includes logfile name, send stdout to that file
# This avoids e-mail every time the script runs from crontabs
#----------------------------------------------------------------
while getopts t:l: optionName
do
            case $optionName in
            t)   export TIME_OFFSET0="$OPTARG"  ;;
            l)   filename="$OPTARG"
                 datestring=`date -u +%Y%m%d.%j.%H%M`
#                datestring=`date -u +%j`
                 exec >> $LOGDIR/$filename.$datestring.log 2>&1 ;;
            ?)   echo "Usage: $scriptname  -l logfile_name \n";;
           esac
done


echo "===================================================="
echo "Begin $scriptname  at  $(date -u)"

cd $datadir


# Selects epoch for field generation. Suppose currect is hh:mm
# Image epochs will be (hh-2):45, (hh-1):15, and (hh-1):45 for GOES_NE case
# -- corresponding to $TargetTimeA, $TargetTimeB and  $TargetTimeC, respectively
#-------------------------------------------------------------------------
DATE=$(  date -u +%Y%j  -d'  0 hour ago ' )
HOUR=$(  date -u +%H    -d'  0 hour ago ' )
DATE0=$(  date -u +%Y%j  -d' 1 hour ago ' )
HOUR0=$(  date -u +%H    -d' 1 hour ago ' )
DATE1=$(  date -u +%Y%j  -d' 2 hour ago ' )
HOUR1=$(  date -u +%H    -d' 2 hour ago ' )
CYD=$( date -u +%Y%j  -d' 1 day ago ' )

# GOES_NE --- (hh-2):45    |  (hh-1):15                |  (hh-1):45
#----
DSN_SST='LD/GOES_NE_SST'
DSN_PCLR='LD/GOES_NE_PCLR'

#TargetTimeA=" DAY=$DATE1   TIME=$HOUR1:26  $HOUR1:58 "
#TargetTimeB=" DAY=$DATE0   TIME=$HOUR0:00  $HOUR0:25 "
#TargetTimeC=" DAY=$DATE0   TIME=$HOUR0:26  $HOUR0:58 "
 TargetTimeA=" DAY=$DATE1   TIME=$HOUR1:00  $HOUR1:25 "
 TargetTimeB=" DAY=$DATE1   TIME=$HOUR1:26  $HOUR1:58 "
 TargetTimeC=" DAY=$DATE0   TIME=$HOUR0:00  $HOUR0:25 "


echo GOES_NE =====================================================

## Copy the band 1 of SST AREA file with time reference $TargetTimeA, $TargetTimeB,
#    $TargetTimeC, to LD/A.8540, LD/A.8541, LD/A.8542, respectively.
#  Copy the band 3 of Pclear AREA file with time reference $TargetTimeA, $TargetTimeB,
#    $TargetTimeC, and $TargetTimeD to LD/A.7540, LD/A.7541, LD/A.7542,  respectively
#  Files AREA8540--8542 and files AREA7540--7542 will be used by program mergeb1.
#---------------------------------------------------------------------------------------------------
Images=' '

   echo " imglist.k    $DSN_SST   $TargetTimeA    "
   doecho  imglist.k   $DSN_SST   $TargetTimeA
   doecho  imglist.k   $DSN_SST   $TargetTimeB
   doecho  imglist.k   $DSN_SST   $TargetTimeC

   imgdel.k LD/A.8540 8542
   imgdel.k LD/A.7540 7542
   echo " imgcopy.k  $DSN_SST   LD/A.8540 $TargetTimeA  SIZE=SAME BAND=1 "
          imgcopy.k  $DSN_SST   LD/A.8540 $TargetTimeA  SIZE=SAME BAND=1   &&  Images=" $Images 8540 "
          imgcopy.k  $DSN_SST   LD/A.8541 $TargetTimeB  SIZE=SAME BAND=1   &&  Images=" $Images 8541 "
          imgcopy.k  $DSN_SST   LD/A.8542 $TargetTimeC  SIZE=SAME BAND=1   &&  Images=" $Images 8542 "
   doecho imgcopy.k  $DSN_PCLR  LD/A.7540 $TargetTimeA  SIZE=SAME BAND=3
   doecho imgcopy.k  $DSN_PCLR  LD/A.7541 $TargetTimeB  SIZE=SAME BAND=3
   doecho imgcopy.k  $DSN_PCLR  LD/A.7542 $TargetTimeC  SIZE=SAME BAND=3

      echo " TargetTimeA = $TargetTimeA "
      echo " TargetTimeB = $TargetTimeB "
      echo " TargetTimeC = $TargetTimeC "
      echo
imglist.k LD/A.8540 8542
echo  "Images=$Images"

[[ $Images == " " ]]  &&  img_GOES_NE="NO"  ||  img_GOES_NE="YES"


# GOES_NW --- (hh-1):00    |  (hh-1):30                |   hh:00 
#------
DSN_SST='LD/GOES_NW_SST'
DSN_PCLR='LD/GOES_NW_PCLR'

#TargetTimeA=" DAY=$DATE0   TIME=$HOUR0:00  $HOUR0:00 "
#TargetTimeB=" DAY=$DATE0   TIME=$HOUR0:25  $HOUR0:35 "
#TargetTimeC=" DAY=$DATE    TIME=$HOUR:00   $HOUR:00 "
 TargetTimeA=" DAY=$DATE1   TIME=$HOUR1:25  $HOUR1:35 "
 TargetTimeB=" DAY=$DATE0   TIME=$HOUR0:00  $HOUR0:00 "
 TargetTimeC=" DAY=$DATE0   TIME=$HOUR0:25  $HOUR0:35 "

echo GOES_NW ===================================================

## Copy the band 1 of SST AREA file with time reference $TargetTimeA, $TargetTimeB,
#    $TargetTimeC, to LD/A.8640, LD/A.8641, LD/A.8642, respectively.
#  Copy the band 3 of Pclear AREA file with time reference $TargetTimeA, $TargetTimeB,
#    $TargetTimeC, and $TargetTimeD to LD/A.7640, LD/A.7641, LD/A.7642,  respectively
#  Files AREA8640--8642 and files AREA7640--7642 will be used by program mergeb1.
#---------------------------------------------------------------------------------------------------
Images=' '

   echo " imglist.k    $DSN_SST   $TargetTimeA    "
   doecho  imglist.k   $DSN_SST   $TargetTimeA
   doecho  imglist.k   $DSN_SST   $TargetTimeB
   doecho  imglist.k   $DSN_SST   $TargetTimeC

   imgdel.k LD/A.8640 8642
   imgdel.k LD/A.7640 7642
   echo " imgcopy.k  $DSN_SST   LD/A.8640 $TargetTimeA  SIZE=SAME BAND=1 "
          imgcopy.k  $DSN_SST   LD/A.8640 $TargetTimeA  SIZE=SAME BAND=1   &&  Images=" $Images 8640 "
          imgcopy.k  $DSN_SST   LD/A.8641 $TargetTimeB  SIZE=SAME BAND=1   &&  Images=" $Images 8641 "
          imgcopy.k  $DSN_SST   LD/A.8642 $TargetTimeC  SIZE=SAME BAND=1   &&  Images=" $Images 8642 "
   doecho imgcopy.k  $DSN_PCLR  LD/A.7640 $TargetTimeA  SIZE=SAME BAND=3
   doecho imgcopy.k  $DSN_PCLR  LD/A.7641 $TargetTimeB  SIZE=SAME BAND=3
   doecho imgcopy.k  $DSN_PCLR  LD/A.7642 $TargetTimeC  SIZE=SAME BAND=3

      echo " TargetTimeA = $TargetTimeA "
      echo " TargetTimeB = $TargetTimeB "
      echo " TargetTimeC = $TargetTimeC "
      echo
imglist.k LD/A.8640 8642
echo  "Images=$Images"

[[ $Images == " " ]]  &&  img_GOES_NW="NO"  ||  img_GOES_NW="YES"


# GOES_SE --- (hh-2):39/45 |  (hh-1):09/15 ((hh-2):45) |  (hh-1):39/45
#-----
DSN_SST='LD/GOES_SE_SST'
DSN_PCLR='LD/GOES_SE_PCLR'

#TargetTimeA=" DAY=$DATE1   TIME=$HOUR1:26  $HOUR1:58 "
#TargetTimeB=" DAY=$DATE0   TIME=$HOUR0:00  $HOUR0:25 "
#TargetTimeC=" DAY=$DATE0   TIME=$HOUR0:26  $HOUR0:58 "
 TargetTimeA=" DAY=$DATE1   TIME=$HOUR1:00  $HOUR1:25 "
 TargetTimeB=" DAY=$DATE1   TIME=$HOUR1:26  $HOUR1:58 "
 TargetTimeC=" DAY=$DATE0   TIME=$HOUR0:00  $HOUR0:25 "

 echo GOES_SE ==================================================

## Copy the band 1 of SST AREA file with time reference $TargetTimeA, $TargetTimeB,
#    $TargetTimeC, to LD/A.8740, LD/A.8741, LD/A.8742, respectively.
#  Copy the band 3 of Pclear AREA file with time reference $TargetTimeA, $TargetTimeB,
#    $TargetTimeC, and $TargetTimeD to LD/A.7740, LD/A.7741, LD/A.7742,  respectively
#  Files AREA8740--8742 and files AREA7740--7742 will be used by program mergeb1.
#---------------------------------------------------------------------------------------------------
Images=' '
 
   echo " imglist.k    $DSN_SST   $TargetTimeA    "
   doecho  imglist.k   $DSN_SST   $TargetTimeA
   doecho  imglist.k   $DSN_SST   $TargetTimeB
   doecho  imglist.k   $DSN_SST   $TargetTimeC

   imgdel.k LD/A.8740 8742
   imgdel.k LD/A.7740 7742
   echo " imgcopy.k  $DSN_SST   LD/A.8740 $TargetTimeA  SIZE=SAME BAND=1 "
          imgcopy.k  $DSN_SST   LD/A.8740 $TargetTimeA  SIZE=SAME BAND=1   &&  Images=" $Images 8740 "
          imgcopy.k  $DSN_SST   LD/A.8741 $TargetTimeB  SIZE=SAME BAND=1   &&  Images=" $Images 8741 "
          imgcopy.k  $DSN_SST   LD/A.8742 $TargetTimeC  SIZE=SAME BAND=1   &&  Images=" $Images 8742 "
   doecho imgcopy.k  $DSN_PCLR  LD/A.7740 $TargetTimeA  SIZE=SAME BAND=3
   doecho imgcopy.k  $DSN_PCLR  LD/A.7741 $TargetTimeB  SIZE=SAME BAND=3
   doecho imgcopy.k  $DSN_PCLR  LD/A.7742 $TargetTimeC  SIZE=SAME BAND=3

      echo " TargetTimeA = $TargetTimeA "
      echo " TargetTimeB = $TargetTimeB "
      echo " TargetTimeC = $TargetTimeC "
      echo
imglist.k LD/A.8740 8742
echo  "Images=$Images"

[[ $Images == " " ]]  &&  img_GOES_SE="NO"  ||  img_GOES_SE="YES"


# GOES_SW --- (hh-2):52    |  (hh-1):22    ((hh-1):00) |  (hh-1):52 
#-----
DSN_SST='LD/GOES_SW_SST'
DSN_PCLR='LD/GOES_SW_PCLR'

#TargetTimeA=" DAY=$DATE1   TIME=$HOUR1:46  $HOUR1:58 "
#TargetTimeB=" DAY=$DATE0   TIME=$HOUR0:00  $HOUR0:25 "
#TargetTimeC=" DAY=$DATE0   TIME=$HOUR0:46  $HOUR0:58 "
 TargetTimeA=" DAY=$DATE1   TIME=$HOUR1:00  $HOUR1:25 "
 TargetTimeB=" DAY=$DATE1   TIME=$HOUR1:46  $HOUR1:58 "
 TargetTimeC=" DAY=$DATE0   TIME=$HOUR0:00  $HOUR0:25 "

 echo GOES_SW ===================================================

## Copy the band 1 of SST AREA file with time reference $TargetTimeA, $TargetTimeB,
#    $TargetTimeC, to LD/A.8840, LD/A.8841, LD/A.8842, respectively.
#  Copy the band 3 of Pclear AREA file with time reference $TargetTimeA, $TargetTimeB,
#    $TargetTimeC, and $TargetTimeD to LD/A.7840, LD/A.7841, LD/A.7842,  respectively
#  Files AREA8740--8742 and files AREA7840--7842 will be used by program mergeb1.
#---------------------------------------------------------------------------------------------------
Images=' '

   echo " imglist.k    $DSN_SST   $TargetTimeA    "
   doecho  imglist.k   $DSN_SST   $TargetTimeA
   doecho  imglist.k   $DSN_SST   $TargetTimeB
   doecho  imglist.k   $DSN_SST   $TargetTimeC

   imgdel.k LD/A.8840 8842
   imgdel.k LD/A.7840 7842
   echo " imgcopy.k  $DSN_SST   LD/A.8840 $TargetTimeA  SIZE=SAME BAND=1 "
          imgcopy.k  $DSN_SST   LD/A.8840 $TargetTimeA  SIZE=SAME BAND=1   &&  Images=" $Images 8840 "
          imgcopy.k  $DSN_SST   LD/A.8841 $TargetTimeB  SIZE=SAME BAND=1   &&  Images=" $Images 8841 "
          imgcopy.k  $DSN_SST   LD/A.8842 $TargetTimeC  SIZE=SAME BAND=1   &&  Images=" $Images 8842 "
   doecho imgcopy.k  $DSN_PCLR  LD/A.7840 $TargetTimeA  SIZE=SAME BAND=3
   doecho imgcopy.k  $DSN_PCLR  LD/A.7841 $TargetTimeB  SIZE=SAME BAND=3
   doecho imgcopy.k  $DSN_PCLR  LD/A.7842 $TargetTimeC  SIZE=SAME BAND=3

      echo " TargetTimeA = $TargetTimeA "
      echo " TargetTimeB = $TargetTimeB "
      echo " TargetTimeC = $TargetTimeC "
      echo
imglist.k LD/A.8840 8842
echo  "Images=$Images"

[[ $Images == " " ]]  &&  img_GOES_SW="NO"  ||  img_GOES_SW="YES"


echo '======================================================'
echo ' Strat merging ..................'
echo

# It is assumed that there are AREA files:
#            8540-8542 (NE), 8740-8742 (SE)
#            8640-8642 (NW), 8840-8842 (SW)
#       and
#            7540-7542 (NE), 7740-7742 (SE)
#            7640-7642 (NW), 7840-7842 (SW)
#  Those AREA Files will be used by program mergeb1.
#---------------------------------------------------------------------------------------------------

hundred="5 6 7 8"
for num in $hundred
do
    imglist.k LD/A.8${num}40 8${num}42 
done

echo " "
# Make hourly gridded product at EPOCH=$DATE0  $HOUR0 (previous hour of present)
#  by calling mergeb1.daynite_test.k (program mergeb1 need input files of A.8540--8542
#  and A.7540--7542, ..., with desires time reference),then send the results to server 
#  -- Once per hour
#--------------------------------------------------------------------------------
 echo 
 echo "============================================="
 echo "Making hourly products ..."
 echo "------------------------------"
 if [[ $img_GOES_NE == "NO" && $img_GOES_SE == "NO" ]]; then
        echo "No area files exist for goesE mergeb1"
 else
        echo "ready to run goesE-merge at   $(date -u)"
        echo "$bindir/mergeb1.daynite_test.k  EPOCH=$DATE0  $HOUR0 SAT=1 COAST=0 "
        time  $bindir/mergeb1.daynite_test.k  EPOCH=$DATE0  $HOUR0 SAT=1 COAST=0
 fi
 echo "------------------------------"
 if [[ $img_GOES_NW == "NO" && $img_GOES_SW == "NO" ]]; then
        echo "No area files exist for goesW mergeb1"
 else
        echo "ready to run goesW-merge at   $(date -u)"
        echo "$bindir/mergeb1.daynite_test.k  EPOCH=$DATE0  $HOUR0 SAT=2 COAST=0 "
        time $bindir/mergeb1.daynite_test.k  EPOCH=$DATE0  $HOUR0 SAT=2 COAST=0 
 fi
 echo "------------------------------"
 if [[ $img_GOES_NE == "NO" && $img_GOES_SE == "NO" && $img_GOES_NW == "NO" && $img_GOES_SW == "NO" ]]; then
        echo "No area files exist for goes mergeb1"
 else
        echo "ready to run goes-merge at   $(date -u)"
        echo "$bindir/mergeb1.daynite_test.k  EPOCH=$DATE0  $HOUR0 SAT=3 COAST=0 "
        time  $bindir/mergeb1.daynite_test.k  EPOCH=$DATE0  $HOUR0 SAT=3 COAST=0

 	rc_merge1=$?
	if [ $rc_merge1 -eq 0 ]
	then
   		echo "1-hourly generate SUCCESS"
	else
   		echo "1-hourly generate FAIL"
	fi

 	echo "Finished 'mergeb1.daynite_test.k'  at  $(date -u) ---- rc=$rc_merge1"

#timeString=$( echo " $DATE0 $HOUR0 " | awk '{printf("%4.4d_%3.3d_%2.2d", $1/1000,$1%1000,$2)}' )

 	ccyy1H=$( echo $DATE0|cut -c1-4 )
 	ddd1H=$(  echo $DATE0|cut -c5-7 )
 	hh1H=$HOUR0
 	timeString1H="${ccyy1H}_${ddd1H}_${hh1H}"     # time-string of hourly product name

 	echo " Sending product for time $timeString1H "
 #grep T "$isOps"   &&   send1b_goes.dist1.sh   $timeString1H
 #grep T "$isTest"  &&   send1b_goes.distn1.sh  $timeString1H
	echo "isOps = $isOps"       |grep TRUE   &&   $SCRIPTDIR/send1b_goes_daynite.sh  $timeString1H  isOps
 	echo "isTest = $isTest"     |grep TRUE   &&   $SCRIPTDIR/send1b_goes_daynite.sh  $timeString1H  isTest
 	echo "isBackup = $isBackup" |grep TRUE   &&   $SCRIPTDIR/send1b_goes_daynite.sh  $timeString1H  isBackup
 
# -- temp
#  	send1b_goes.sh  $timeString1H  isTest
fi

# define intH0
#-------------
let intH0='100'${HOUR0}%100

#--------------------------------------------------------------------------------
# Make 3-hourly average gridded product
#    (after making 1Z or 4Z or... hourly product)
#  then send the results to server
#  -- Once per 3 hours (weight average of SST at $HOUR1-1, $HOUR1, $HOUR1+1)
#--------------------------------------------------------------------------------
if [ $( expr $intH0 % 3 ) -eq 1 ]; then
    echo
    echo "============================================="
    echo "Making three-hour product"
    echo "$bindir/mergeb3.k  EPOCH=$DATE1 $HOUR1  SAT=3 COAST=1   "
          $bindir/mergeb3.k  EPOCH=$DATE1 $HOUR1  SAT=3 COAST=1   
    rc_merge3=$?
          $bindir/mergeb3.k  EPOCH=$DATE1 $HOUR1  SAT=1 COAST=0
          $bindir/mergeb3.k  EPOCH=$DATE1 $HOUR1  SAT=2 COAST=0
    if [ $rc_merge3 -eq 0 ]
    then
       echo "3-hourly generate SUCCESS"
    else
       echo "3-hourly generate FAIL"
    fi
    echo "Finished 'mergeb3.k'  at  $(date -u) ---- rc=$rc_merge3"

    ccyy3H=$( echo $DATE1|cut -c1-4 )
    ddd3H=$(  echo $DATE1|cut -c5-7 )
    hh3H=$HOUR1
    timeString3H="${ccyy3H}_${ddd3H}_${hh3H}"   #### time-string of 3-hr product name

    echo "timeString3H=$timeString3H"

   #send3b_goes.sh  $timeString3H
#   grep T "$isOps"   &&   send3b_goes.dist1.sh   $timeString3H
#   grep T "$isTest"  &&   send3b_goes.distn1.sh  $timeString3H
    echo "isOps = $isOps"       |grep TRUE   &&   $SCRIPTDIR/send3b_goes.sh  $timeString3H  isOps
    echo "isTest = $isTest"     |grep TRUE   &&   $SCRIPTDIR/send3b_goes.sh  $timeString3H  isTest
    echo "isBackup = $isBackup" |grep TRUE   &&   $SCRIPTDIR/send3b_goes.sh  $timeString3H  isBackup
fi

#--------------------------------------------------------------------------------
# Make daily average gridded product for Yesterday by calling mergeb24_goes.k,
#   (after making  4Z hourly product for Today)
#  then send the results to server 
#  -- Once per day
#--------------------------------------------------------------------------------
#### Change this to run at  3:30Z, like on satepsprod1  (rip  22apr2010)
### if [ $( expr $intH0 % 24 ) -eq 4 ]; then
if [ $( expr $intH0 % 24 ) -eq 2 ]; then
    echo
    echo "============================================="
    echo "Making daily product"

    echo "$bindir/mergeb24.k EPOCH=$CYD  SAT=3 COAST=0   "
          $bindir/mergeb24.k EPOCH=$CYD  SAT=3 COAST=0   
          $bindir/mergeb24.k EPOCH=$CYD  SAT=1 COAST=0
          $bindir/mergeb24.k EPOCH=$CYD  SAT=2 COAST=0
    rc_merge24=$?
    if [ $rc_merge24 -eq 0 ]
    then
       echo "daily generate SUCCESS"
    else
       echo "daily generate FAIL"
    fi
    echo "Finished 'mergeb24.k'  at  $(date -u) ---- rc=$rc_merge24"

    ccyy24H=` echo  ${CYD} |cut -c1-4 `
    ddd24H=`  echo  ${CYD} |cut -c5-7 `
    timeString24H="${ccyy24H}_${ddd24H}"   #### time-string of 24-hr product name -- previous day

    echo "timeString24H=$timeString24H"
       
#   grep T "$isOps"   &&   send24b_goes.dist1.sh   $timeString24H
#   grep T "$isTest"  &&   send24b_goes.distn1.sh  $timeString24H
    echo "isOps = $isOps"       |grep TRUE   &&   $SCRIPTDIR/send24b_goes.sh  $timeString24H  isOps
    echo "isTest = $isTest"     |grep TRUE   &&   $SCRIPTDIR/send24b_goes.sh  $timeString24H  isTest
    echo "isBackup = $isBackup" |grep TRUE   &&   $SCRIPTDIR/send24b_goes.sh  $timeString24H  isBackup
fi

#--------------------------------------------------------------------------------
echo "Completed  $scriptname  at  $(date -u)"
echo "===================================================="
