#!/bin/bash
#
#######################################################################################
#
# Program Name: merge_mtsat.sh
#
# Purpose:   generate MTSAT SST gridded fields (hourly, 3-hourly, and daily)  
#            and distribute to product server.
#
# Usage: merge_mtsat.sh [-l {logfile_name}]
#    -l {logfile_name}: if command line includes logfile name, send stdout to the file
#                       $logfile_name.$datestring.log, where datestring=`date -u +%j.%H%M`,
#                       the time that the script start to run.
#
# Prerequisite: Runs after proc_mtsat.sh put the SST and Pclear AREA files to LD/MTSAT_SST and
#               LD/MTSAT_PCLR, respectively.
#
# Called by: None
#
# Description: Select MTSAT SST and Pclear AREA files, then run merge program to
#              generate SST and Pclear grid field files,and send them to product server
#          1. Set time reference to choose MTSAT SST and Pclear AREA files
#             Suppose current time is hh:mm, the selected epoch should be the one at hh-2:30
#             to produce SST hourly at hh-1.
#          2. Perform hourly merge to generate hourly grid SST and PClear,
#             then send to product server
#             -- 1 hour back from current (once per hour)
#          3. Perform 3-hourly merge to .......
#             -- 2 hour back from current when current is 04Z, 07Z,... (once per 3 hr) 
#          4. Perform daily merge to ........
#             -- one day back from current when current is 04Z (once per day) 
#
# Scripts called:
#          1. set_app_env.sh
#          2. send1b_mtsat.sh
#          3. send3b_mtsat.sh
#          4. send24b_mtsat.sh
#          5. set_server_Ops.sh, set_server_Test.sh, or set_server_Backup.sh by (2, 3, 4)
#
# Program called:
#          1. mergeb1.k
#          2. mergeb3.k
#          3. mergeb24.k
#
# Change History:
#      07/12/27  Modified from procCrtmA_L2P.sh for MTSAT?
#      09/03/13  M. Fan (PSGS)
#                1) Add comment blocks
#                2) Use set_app_env.sh
#                3) Apply 2009 version of merge programs
#              -- modified from merge_msg.sh (2009 version)
#
#######################################################################################

doecho() { echo $@ ; eval $@ ; }

## Set directories and  environment variables
#---------------------------------------------
export SCRIPTDIR=$( dirname $0 )
. $SCRIPTDIR/set_app_env.sh
scriptname=$( basename $0)
 

#bindir=$HOME/mcidas/bin
#datadir=$HOME/mcidas/data
bindir=$BINDIR
datadir=$MCDATDIR

DSN_SST='LD/MTSAT_SST'
DSN_PCLR='LD/MTSAT_PCLR'

# info from PROC.TABLE: scripts and other viriables
#------------------------------------------------
## set TABLE name
table=$SCRIPTDIR/PROC.TABLE
# region name
#----
RegName=MTSAT
## get all info related with $RegName
#----
RegInfo=$( grep -ve ^# $table | grep -e $RegName )
isOps=$( echo $RegInfo | awk -F\, '{print $2}' | awk -F\/ '{print $1}' )
isTest=$( echo $RegInfo | awk -F\, '{print $2}' | awk -F\/ '{print $2}' )
isBackup=$( echo $RegInfo | awk -F\, '{print $2}' | awk -F\/ '{print $3}' )


# set log file:
# If command line includes logfile name, send stdout to that file
# This avoids e-mail every time the script runs from crontabs
#----------------------------------------------------------------
while getopts t:l: optionName
do
            case $optionName in
            t)   export TIME_OFFSET0="$OPTARG"  ;;
            l)   filename="$OPTARG"
                 datestring=`date -u +%Y%m%d.%j.%H%M`
#                datestring=`date -u +%j`
                 exec >> $LOGDIR/$filename.$datestring.log 2>&1 ;;
            ?)   echo "Usage: $scriptname  -l logfile_name \n";;
           esac
done


echo "===================================================="
echo "Begin $scriptname  at  $(date -u)"

cd $datadir

# Selects epoch for field generation. Suppose currect is hh:mm
# Image epochs will be (hh-1):30 -- corresponding to $TargetTimeA 
# (hourly product will be the one at (hh1) )
#-------------------------------------------------------------------------
DATE0=$(  date -u +%Y%j  -d' 0 hour ago ' )
HOUR0=$(  date -u +%H    -d' 0 hour ago ' )
DATE1=$(  date -u +%Y%j  -d' 1 hour ago ' )
HOUR1=$(  date -u +%H    -d' 1 hour ago ' )
CYD=$( date -u +%Y%j  -d' 1 day ago ' )

# TargetTimeA=" DAY=$DATE1   TIME=$HOUR1:30  $HOUR1:35 "
 TargetTimeA=" DAY=$DATE1   TIME=$HOUR1:30  $HOUR1:35 "

      echo " DATE0,HOUR0 = $DATE0  $HOUR0"
      echo " DATE1,HOUR1 = $DATE1  $HOUR1"

      echo " TargetTimeA = $TargetTimeA "
      echo
      echo ================================================================================


## Copy the band 1 of SST AREA file with time reference $TargetTimeA to LD/A.8162.
#  Copy the band 3 of Pclear AREA file with time reference $TargetTimeA to LD/A.7162.
#  Files AREA8162 and  AREA7162 will be used by program mergeb1.
#-------------------------------------------------------------------------------------------
Images=' '

   echo  " imglist.k   $DSN_SST   $TargetTimeA    "
   doecho  imglist.k   $DSN_SST   $TargetTimeA    
     
   imgdel.k LD/A.8162  
   imgdel.k LD/A.7162  
   echo  " imgcopy.k   $DSN_SST   LD/A.8162 $TargetTimeA  SIZE=SAME BAND=1"
           imgcopy.k   $DSN_SST   LD/A.8162 $TargetTimeA  SIZE=SAME BAND=1   &&  Images=" $Images 8162 "
   doecho  imgcopy.k   $DSN_PCLR  LD/A.7162 $TargetTimeA  SIZE=SAME BAND=3


imglist.k LD/A.8162  
echo  "Images=$Images"

# Make hourly gridded product at EPOCH=$DATE0  $HOUR0 (previous hour of present)
#  by calling mergeb1.k (program mergeb1 need input files of A.8162 and A.7162
#  for MTSAT),then send the results to server 
#  -- Once per hour
#--------------------------------------------------------------------------------
 echo 
 echo "============================================="
 if [[ $Images == " " ]]; then
        echo "No area files exist for mergeb1"
 else
	echo "ready to run merge_mtsat at   $(date -u)"
	echo "$bindir/mergeb1.k  EPOCH=$DATE0  $HOUR0 SAT=4 COAST=0 "
	time  $bindir/mergeb1.k  EPOCH=$DATE0  $HOUR0 SAT=4 COAST=0 
 	rc_merge1=$?
	if [ $rc_merge1 -eq 0 ]
	then
   		echo "1-hourly generate SUCCESS"
	else
   		echo "1-hourly generate FAIL"
	fi

 	echo "Finished 'mergeb1.k'  at  $(date -u) ---- rc=$rc_merge1"

#timeString=$( echo " $DATE0 $HOUR0 " | awk '{printf("%4.4d_%3.3d_%2.2d", $1/1000,$1%1000,$2)}' )

#let ccyy=$DATE0/1000
#let  ddd=$DATE0%1000
	ccyy1H=$( echo $DATE0|cut -c1-4 )
 	ddd1H=$(  echo $DATE0|cut -c5-7 )
 	hh1H=$HOUR0
 	timeString1H="${ccyy1H}_${ddd1H}_${hh1H}"     # time-string of hourly product name

 	echo " Sending product for time $timeString1H "
 	echo "isOps = $isOps"       |grep TRUE   &&   $SCRIPTDIR/send1b_mtsat.sh  $timeString1H   isOps
 	echo "isTest = $isTest"     |grep TRUE   &&   $SCRIPTDIR/send1b_mtsat.sh  $timeString1H   isTest
 	echo "isBackup = $isBackup" |grep TRUE   &&   $SCRIPTDIR/send1b_mtsat.sh  $timeString1H   isBackup
 
# -- temp
# 	send1b_mtsat.sh  $timeString1H   isTest
 fi


# define intH0
#-------------
let intH0='100'${HOUR0}%100


#--------------------------------------------------------------------------------
# Make 3-hourly average gridded product
#    (after making 1Z or 4Z or... hourly product)
#  then send the results to server
#  -- Once per 3 hours (weight average of SST at $HOUR1-1, $HOUR1, $HOUR1+1)
#--------------------------------------------------------------------------------
if [ $( expr $intH0 % 3 ) -eq 1 ]; then
    echo
    echo "============================================="
    echo "Making three-hour product"
    echo "$bindir/mergeb3.k  EPOCH=$DATE1 $HOUR1  SAT=4 COAST=0   "

          $bindir/mergeb3.k  EPOCH=$DATE1 $HOUR1  SAT=4 COAST=0   

    rc_merge3=$?
    if [ $rc_merge3 -eq 0 ]
    then
       echo "3-hourly generate SUCCESS"
    else
       echo "3-hourly generate FAIL"
    fi

    echo "Finished 'mergeb3.k'  at  $(date -u) ---- rc=$rc_merge3"

    ccyy3H=$( echo $DATE1|cut -c1-4 )
    ddd3H=$(  echo $DATE1|cut -c5-7 )
    hh3H=$HOUR1
    timeString3H="${ccyy3H}_${ddd3H}_${hh3H}"   #### time-string of 3-hr product name

    echo "timeString3H=$timeString3H"

    echo "isOps = $isOps"       |grep TRUE   &&   $SCRIPTDIR/send3b_mtsat.sh  $timeString3H   isOps
    echo "isTest = $isTest"     |grep TRUE   &&   $SCRIPTDIR/send3b_mtsat.sh  $timeString3H   isTest
    echo "isBackup = $isBackup" |grep TRUE   &&   $SCRIPTDIR/send3b_mtsat.sh  $timeString3H   isBackup
fi

#--------------------------------------------------------------------------------
# Make daily average gridded product for Yesterday by calling mergeb24.k,
#   (after making  4Z hourly product for Today)
#  then send the results to server 
#  -- Once per day
#--------------------------------------------------------------------------------
if [ $( expr $intH0 % 24 ) -eq 4 ]; then
    echo
    echo "============================================="
    echo "Making daily product"

#   CYD=$($SCRIPTDIR/Yesterday)

    echo "$bindir/mergeb24.k EPOCH=$CYD  SAT=4 COAST=0   "
          $bindir/mergeb24.k EPOCH=$CYD  SAT=4 COAST=0   

    rc_merge24=$?
    if [ $rc_merge24 -eq 0 ]
    then
       echo "daily generate SUCCESS"
    else
       echo "daily generate FAIL"
    fi

    echo "Finished 'mergeb24.k'  at  $(date -u) ---- rc=$rc_merge24"

    ccyy24H=` echo  ${CYD} |cut -c1-4 `
    ddd24H=`  echo  ${CYD} |cut -c5-7 `
    timeString24H="${ccyy24H}_${ddd24H}"   #### time-string of 24-hr product name -- previous day

    echo "timeString24H=$timeString24H"
       
    echo "isOps = $isOps"       |grep TRUE   &&   $SCRIPTDIR/send24b_mtsat.sh  $timeString24H   isOps
    echo "isTest = $isTest"     |grep TRUE   &&   $SCRIPTDIR/send24b_mtsat.sh  $timeString24H   isTest
    echo "isBackup = $isBackup" |grep TRUE   &&   $SCRIPTDIR/send24b_mtsat.sh  $timeString24H   isBackup
fi

#--------------------------------------------------------------------------------
echo "Completed  $scriptname  at  $(date -u)"
echo "===================================================="
