#!/bin/bash
#
#########################################################################################
#
# Program Name: proc_mtsat.sh
#
# Purpose: run modularized bayesian program to generate SST retrievals
#          also performs L2P/netCDF conversion -- for MTSAT
#
# Usage:   proc_mtsat.sh    [-l {logfile_name}]
#    -l {logfile_name}: if command line includes logfile name, send stdout to the file
#                       $logfile_name.$datestring.log, where datestring=`date -u +%j.%H%M`,
#                       the time that the script  start to run. 
#
# Description: Performs main Bayesian SST process and L2P generation,distribution. 
#              Three steps are included in script proc_mtsat.sh:
#          1. Prepare: to get satellite data and model data
#          2. Generate SST and Pclear AREA files
#            (1) Running the main Bayesian SST processing program ( run_gbcs.sh)
#                to generate SST product as multi-band AREA files.
#            (2) Copy the SST, PCLR and ancillary files to area loop:
#                   LD/MTSAT_SST   ---- Output SST (bands 1-2)
#                   LD/MTSAT_PCLR  ---- Output Pclear (3-6)
#                   LD/MTSAT_RTM   ---- Output Ancillary (10-20)
#          3. Generate L2P and distribute to server
#
# Scripts called:
#           1. set_app_env.sh
#           2. getdata_mtsat.sh
#           3. run_gbcs.sh
#           4. L2P_clean.sh
#           5. L2P_proc.sh
#
# Export variable: age (in order to be used by getdat_mtsat.sh)
#
# Change History:
# 09/03/30 M. Fan  (PSGS)
#         --- modified from proc_msg 2009 version
#
#######################################################################################

doecho() { echo $@ ; eval $@ ; }

## Set directories and  environment variables
#---------------------------------------------
export SCRIPTDIR=$( dirname $0 )
. $SCRIPTDIR/set_app_env.sh
scriptname=$( basename $0)

# set log file:
# If command line includes logfile name, send stdout to that file
# This avoids e-mail every time the script runs from crontabs
#---------------------------------------------------------------
 while getopts l: optionName
 do
             case $optionName in
             l)   logname="$OPTARG"
                  datestring=`date -u +%Y%m%d.%j.%H%M` 
                  logname="$logname.$datestring.log"
                  export   LOGFILE=$LOGDIR/$logname
                  exec >> $LOGFILE   2>&1 ;;
             ?)   echo "Usage: $scriptname -l logfile_name \n";;
            esac
 done

echo "Begin $scriptname $* at $(date)"

## Variables for processing....
#---------------------------------
RegName=MTSAT
# info from PROC.TABLE: scripts and other viriables
#----
## set TABLE name
table=$SCRIPTDIR/PROC.TABLE
## get all info related with $RegName
#----
RegInfo=$( grep -ve ^# $table | grep -e $RegName )

#isOps=$( echo $RegInfo | awk -F\, '{print $2}' | awk -F\/ '{print $1}' )
#isTest=$( echo $RegInfo | awk -F\, '{print $2}' | awk -F\/ '{print $2}' )
getdata_script=$( echo $RegInfo | awk -F\, '{print $3}' )
GBCS_INP=$( echo $RegInfo | awk -F\, '{print $4}' )
isL2P=$( echo $RegInfo | awk -F\, '{print $5}' )



## Set time reference
#--------------------------------------------
proc_date=$(date -u +%Y%j)  
proc_hour=$(date -u +%H  )  
proc_mm=$(date -u +%M)
tag_time=$(date -u +%Y%j.%H )   # -- to archive the image

echo " "


#    >>>> step 1: get satellite data and model data <<<<

##---------------------------------------------------------------------
## Get satellite imagery by calling $getdat_script (e.g. getdata_mtsat.sh) 
#  The result is a multi-spectral AREA file located at $DSN_IMG
#---------------------------------------------------------------------
echo
echo "  >>>>Get input imagery "
echo

#  To  get previous hour's data
    echo "proc_mm=$proc_mm"
    export age=60 ; $getdata_script
    rc_image=$?   
    echo "rc_image=$rc_image"


# exit the proc_ program with no further processing if $rc_image=-1
# which means no expected imagery exist
    if [ $rc_image -ne 0 ]; then
        echo "No expected imagery exist"
        echo "Exit the proc_ program with no further processing"
        echo " End $scriptname at $(date)"
        exit 0
    fi


##      >>>>>>>     copy image    <<<<<<<
### Copy the most recent multi-spectral imagery AREA file LD/MTSAT_IMG.0 to LD/A.$inp_area
##   ( A.151 for MTSAT)
#=======================================================================================

 echo "Start image coping ........."


## delete old tmporary image: 
#---------------------------
   imgdel.k  LD/A.155

## copy the most recently image at $DSN_IMG to temporary location
#---------------------------------------------------------------------
   DSN_IMG='LD/MTSAT_IMG'
   imgcopy.k ${DSN_IMG}.0   LD/A.155  SIZE=ALL     # Temporary location

## get time stamp from the temporary image
#-----------------------------------------
   inp_hh="$( imglist.k LD/A.155  |grep 155  |head -1  |awk '{print $6}'  |cut -c1-2)"
   inp_mm="$( imglist.k LD/A.155  |grep 155  |head -1  |awk '{print $6}'  |cut -c4-5)"
   echo "Imagery time = ${inp_hh}:${inp_mm}"
#  quarter=$( expr  1 +  $inp_mm / 15 )
   
## get image area number for retrievals input and out put, i.e 151 and 162
#--------------------------------------------------------------------------
#  inp_area="${quarter}71"
#  out_area="${quarter}82"
   inp_area="151"
   out_area="162"
   grid_0="${out_area}0"    # -- i.e 1620
   grid_1="${out_area}1"    # -- i.e 1621

   echo " inp_area=$inp_area "

## copy image at temporary location to retrievals input ${inp_area}
#----------------------------------------------------------------
    imgcopy.k LD/A.155  LD/A.${inp_area}    SIZE=ALL   
    imglist.k LD/A.$inp_area

   
##          >>>>>>>>     Model Data.      <<<<<<<<<
#  Put the atmosphere profile data to LD/G.${grid_0}, and surface data to LD/G.${grid_1}
# (need getmod.sh put the model data to LD/G_ATM26.$grid_hour and LD/G_SURF.$grid_hour first)
#  For MTSAT, G.1620/1621
#=======================================================================================================

echo " "
echo "Start model data coping..............."
 
# want model data at nearest hour to imagery
#----------------------------------------
#  let hhtemp=100${inp_hh}%100
#  let grid_hour=$hhtemp+quarter/3
#  grid_hour=$inp_hh
   let grid_hour=100${inp_hh}%100
   [ $grid_hour -eq 0 ]  &&  grid_hour=24

   echo " DEBUG: grid_hour=$grid_hour"
   echo " Getting model data for hour=$grid_hour "

# get model data and put to LD/G.${grid_0},and LD/G.${grid_1}
#------------------------------------------------------------------
    echo "Info for LD/G_ATM26.$grid_hour:"
    grdlist.k  LD/G_ATM26.$grid_hour
    if [ $? -eq 0 ]
    then
       grdcopy.k  LD/G_ATM26.$grid_hour    LD/G.${grid_0}  NUM=ALL  DEL=YES
       grdlist.k  LD/G.${grid_0}
       echo " Grid: G.${grid_0}"
    else
       echo "No Model Grid File: G_ATM26.$grid_hour"
    fi

    echo "Info for LD/G_SURF.$grid_hour:"
    grdlist.k  LD/G_SURF.$grid_hour
    if [ $? -eq 0 ]
    then   
        grdcopy.k  LD/G_SURF.$grid_hour   LD/G.${grid_1}  NUM=ALL  DEL=YES
        grdlist.k  LD/G.${grid_1}
        echo " Grid: G.${grid_1}"
    else
        echo "No Model Grid File: G_SURF.$grid_hour "
    fi

echo
echo


# Before processing SST retrievals, clear out old L2P input files
#---------------------------------------------------------------
    echo "isL2P = $isL2P"   |grep "yes"   &&   $SCRIPTDIR/L2P_clean.sh  ${out_area}



#       >>>> step 2: generate SST and Pclear <<<<

#---------------------------------------------------------------------
## Generate SST and Pclear multi-band AREA files by running the main
#  Bayesian SST processing program:
#      LD/A.0$out_area   -- SST
#      LD/A.1$out_area   -- Pclear
#      LD/A.2$out_area   -- ancillary parameters
#     For MTSAT,  $out_area is 162, $inp_area is 151
#---------------------------------------------------------------------
echo
echo '+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++'
echo '+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++'
echo

name=$( basename $SCRIPTDIR/run_gbcs.sh )
numRunning=$( ps -fu $(whoami) |grep $name |grep -v grep |grep -v '0:00:00 ' |wc -l )
if [ $numRunning -gt 2 ]  
then
    echo " Cannot process - too many instances of $name already in progress "
    ps -fu $(whoami) |grep $0
    rc_sst=100
else 
   echo ">>>> `date -u` begin goes_sst for procHour=$proc_hour"

    echo  "$SCRIPTDIR/run_gbcs.sh $GBCS_INP AREA0$inp_area GRID${grid_0} "
    time   $SCRIPTDIR/run_gbcs.sh $GBCS_INP AREA0$inp_area GRID${grid_0}

   rc_sst=$?
   echo "`date -u` done goes_sst for procHour=$proc_hour   rc=$rc_sst "
fi
echo
echo '+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++'
echo '+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++'
echo
echo

## Figure out time of output file and copy result to loop.  
#--------------------------------------------------------
echo
echo "Copying to loop"

imglist.k LD/A.$inp_area
rc1=$?

imglist.k LD/A.$out_area
rc2=$?

if [[ $rc1 -eq 0    &&  $rc2 -eq 0 ]]
then 
  string171="$( imglist.k LD/A.$inp_area |grep $inp_area |head -1 )"
  string182="$( imglist.k LD/A.$out_area |grep $out_area |head -1 )"

  inp_cyd="20$( echo $string171 | awk '{print $5}')"
  out_cyd="20$( echo $string182 | awk '{print $5}')"

  inp_hhmm="$(     echo $string171 | awk '{print $6}'|cut -c1-5)"
  out_hhmm="$(     echo $string182 | awk '{print $6}'|cut -c1-5)"
  out_hh="$(       echo $string182 | awk '{print $6}'|cut -c1-2)"
  out_mm="$(       echo $string182 | awk '{print $6}'|cut -c4-5)"

  echo "input epoch  = $inp_cyd.$inp_hhmm "
  echo "output epoch = $out_cyd.$out_hhmm "

  if [[ $out_cyd  =  $inp_cyd ]] && [[ $out_hhmm  =  $inp_hhmm ]]
  then


    echo '+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++'
    echo

## Copy to loop:
#  Copy the SST and PCLR, and ancillary AREA files to (see below):
#------------------------------------------------------------------------------
    DSN_SST=LD/${RegName}_SST
    DSN_PCLR=LD/${RegName}_PCLR
    DSN_RTM=LD/${RegName}_RTM
    imgcopy.k  LD/A.0$out_area   ${DSN_SST}       SIZE=ALL    # Output SST (bands 1-2)
    imgcopy.k  LD/A.1$out_area   ${DSN_PCLR}      SIZE=ALL    # Output Pclear (3-6)
    imgcopy.k  LD/A.2$out_area   ${DSN_RTM}       SIZE=ALL    # Output FFM parms (10-20)

# archive Area files to archive directory
#----------------------------------------------
   ###  cp -p  ${AREADIR}/AREA0${inp_area}      ${oldArea}/AREA0${inp_area}.${tag_time}

  fi
fi


# After processing SST retrievals, NET_CDF conversion -- L2P 
#---------------------------------------------------------------
    echo " Processing L2P ...."
    echo "isL2P = $isL2P"
    echo "isL2P = $isL2P"   |grep "yes"   &&   doecho $SCRIPTDIR/L2P_proc.sh  ${out_area}

echo " End $scriptname at $(date)"

