#!/bin/bash
#
################################################################################
#
# Program Name: run_gbcs.sh
#
# Purpose: To run the GBCS execuatable NOAA_Linux_debug.exe
#
# Usage: $0 $1 $2 $3 
#      $1 =  CONFIG file (Modular Bayesian Control File)
#            e.g.  GOES11N.INP, GOES11S.INP, GOES12N.INP, GOES12S.INP, 
#                  MSG02.INP, MTSAT01.INP  --  default ones
#      $2 = Satellite Image File
#                 AREA0171, AREA0271, AREA0371, AREA0471.
#      $3 = Model data file (first of two)
#                 GRID1000, GRID1200, ....
#      Example:
#           . ./run_gbcs.sh  MSG02.INP  AREA0171  GRID1820 
#
# Scripts called: set_gbcs_env.sh
#
# Basic function
#   This script is the driver that runs Modular Bayesian SST software 
#   to generate SST retrievals.
#   The basic configuration for the retirevals job is specified in the
#   configuration file ($1, such as MSG02.INP).
#   There are three types of variables in each configure file
#   1.  parameters that will be the same from run to run for specified satellite
#       using same configure file, such as which channels to use to generate
#       the retrievals.
#   2.  variables that will be the same form run to run even using different 
#       configure file, such as directory names. For these variables, although 
#       their name are gived in configure files, their vaules are defined in
#       script:  set_gbcs_env.sh
#   3. variables that might be different from run to run, such as names of 
#      particular input data files, number of lines in the input image. 
#      These variables should be defined as global variables in script that calls run_gbcs.sh.

#   This script defines variables, exports them, and invokes the Modular 
#   Bayesian software with the appropriate configuration files. 
#
# -NOTE: Variables corresponding to $2, $3, should be export to $1 so the
#         corresponding variables in $1 can be assigned the value of $2, $3
# 
# Change History:
#       Feb. 2009   M. Fan  (PSGS) --  Initial version
#       Aug. 17, 2009 M. Fan  (PSGS) -- added processing for sensor that is not the default ones,
#                                       e.g. MSG01, MTSAT2R, GOES13, GOES14 
#
################################################################################

# set directories and script name
#-------------------------------
export SCRIPTDIR=$( dirname $0 )
cur_dir=`pwd`
scriptname=$( basename $0 )

# run set_gbcs_env.sh to get environment variables
#--------------------------------------------------
. $SCRIPTDIR/set_gbcs_env.sh

## Usage prompt
#----------------------------
echo "Begin $scriptname $* at $(date)"
if [ $# -ne 3 ]
then
    echo 'USAGE: $scriptname $1 $2 $3'
    exit -1
fi

# get variables from arguments.
# GRID_FILE_NO, IMGAREA, (also $NUM_OF_LINES, $NUM_OF_ELEMENTS)
#  need to be defined or computed and exported to the Unix environments, 
#  so that parameters that are passed to $CONFIG as shell variables 
#  will be defined, with the correct value.  
#---------------------------------------------------------------
export GRID_FILE_NO=$3
export IMGAREA=$2
inp_area=$( echo "$IMGAREA"  | cut -c6-8 )
export NUM_OF_LINES=$( imglist.k LD/A.$inp_area form=exp |grep Band |head -1 |awk '{print $12}' )
export NUM_OF_ELEMENTS=$( imglist.k LD/A.$inp_area form=exp |grep Band |head -1 |awk '{print $14}' )
export satID=$( imglist.k LD/A.$inp_area form=exp | grep ss: | awk -F\: '{print $5}' )
CONFIG=$1

# The default config file is specified in file "PROC.TABLE" (such as MSG02.INP)
# and pass to here as $1.
# In furture, default sensor source might be replaced by other sensor source, and the corresponding
# *.INP file need to be changed. To deal with this possible changes, following code is added to 
# determine which *.INP should be used if the sensor source is not the default ones.
# 
# The sensor source number & its corresponding *.INP file are listed in file "CONFIG.TABLE"
#
# Default sensor source number and the corresponding *.INP file:
#     52  -- MSG02.INP
#     84  -- MTSAT1R.INP
#     76  -- GOES11N.INP/GOES11S.INP
#     78  -- GOES12N.INP/GOES12S.INP

# When sensor source other than the default one is used,
# e.g. MSG02 switchs to MSG01, MTSAT1R switchs to MTSAT2R,
#      or GOES-11/12 switchs to GOES-13 or GOES-14
#--------------
 if [[ $satID -ne 52 &&  $satID -ne 84 && $satID -ne 76 && $satID -ne 78 ]]; then
   if [ $satID -lt 180 ]; then
      CONFIG=$( grep $satID $SCRIPTDIR/CONFIG.TABLE | awk -F\, '{print $2}' )
   else
      nnum=$( echo "$inp_area" | cut -c1-1)
      if [[ $nnum -eq 1 || $nnum -eq 2 || $nnum -eq 5 || $nnum -eq 6 ]]; then
          CONFIG=$( grep $satID $SCRIPTDIR/CONFIG.TABLE | awk -F\, '{print $2}' | awk -F\/ '{print $1}' )
      else
          CONFIG=$( grep $satID $SCRIPTDIR/CONFIG.TABLE | awk -F\, '{print $2}' | awk -F\/ '{print $2}' )
      fi
    fi
fi   

echo "Actual INP file used is $CONFIG"


# To get the NeDTs from NeDT.TABLE 
#---------------------------------
SAT0=$( echo $CONFIG | awk -F\. '{print $1}' )
[[ ${SAT0: -1:1} -eq 'N' || ${SAT0: -1:1} -eq 'S' ]]  && SAT=${SAT0: -7:6} || SAT=${SAT0}
SAT1=$( grep -ve ^# $SCRIPTDIR/NeDT.TABLE | grep -e ${SAT} )
export NeDT1=$( echo ${SAT1} | awk -F\, '{print $2}' )
         echo "$0-DEBUG-  NeDT1=$NeDT1"
export NeDT2=$( echo ${SAT1} | awk -F\, '{print $3}' )
         echo "$0-DEBUG-  NeDT2=$NeDT2"
export NeDT3=$( echo ${SAT1} | awk -F\, '{print $4}' )
         echo "$0-DEBUG-  NeDT3=$NeDT3"
export NeDT4=$( echo ${SAT1} | awk -F\, '{print $5}' )
         echo "$0-DEBUG-  NeDT4=$NeDT4"
echo "NeDT1=$NeDT1, NeDT2=$NeDT2, NeDT3=$NeDT3, NeDT4=$NeDT4"


# go to GBCS work directory where NOAA_Linux_debug.exe and *.INP files located
#-----------------------------------------------------------------------
cd $GBCS_WORK_DIR

# run GBCS SST processing
#------------------------
echo $CONFIG | NOAA_Linux_debug.exe

# go to directory where $0 start to run
#--------------------------------------
cd $cur_dir

echo " End $scriptname at $(date)"

